==> seedsui-react-5.6.78.tgz: package/lib/DatePicker/Combo/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["min", "max", "type", "value", "format", "onError", "ModalProps"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import Combo from "./../../Picker/Combo";
import Modal from "./../Modal";
import Utils from "./Utils";

// 日期选择
import { jsx as _jsx } from "react/jsx-runtime";
export default /*#__PURE__*/forwardRef(function (_ref, ref) {
  var min = _ref.min,
    max = _ref.max,
    type = _ref.type,
    value = _ref.value,
    format = _ref.format,
    onError = _ref.onError,
    ModalProps = _ref.ModalProps,
    props = _objectWithoutProperties(_ref, _excluded);
  // 显示文本
  var displayValue = Utils.getDisplayValue({
    type: type,
    format: format,
    value: value
  });
  var rootRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current, _rootRef$current2, _rootRef$current3, _rootRef$current4, _rootRef$current5, _rootRef$current6;
    return {
      rootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.rootDOM,
      modalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.modalDOM,
      instance: instance.current,
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current3 = rootRef.current) === null || _rootRef$current3 === void 0 ? void 0 : _rootRef$current3.getRootDOM,
      getModalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current4 = rootRef.current) === null || _rootRef$current4 === void 0 ? void 0 : _rootRef$current4.getModalDOM,
      getInstance: function getInstance() {
        return instance.current;
      },
      close: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current5 = rootRef.current) === null || _rootRef$current5 === void 0 ? void 0 : _rootRef$current5.close,
      open: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current6 = rootRef.current) === null || _rootRef$current6 === void 0 ? void 0 : _rootRef$current6.open,
      // 显示文本
      displayValue: displayValue,
      getDisplayValue: function getDisplayValue(newValue) {
        return Utils.getDisplayValue({
          type: type,
          format: format,
          value: newValue || value
        });
      }
    };
  });
  return /*#__PURE__*/_jsx(Combo, _objectSpread(_objectSpread({
    value: displayValue,
    ModalComponent: Modal,
    ModalProps: _objectSpread({
      value: value,
      min: min,
      max: max,
      type: type,
      onError: onError
    }, ModalProps)
  }, props), {}, {
    ref: rootRef
  }));
});

==> seedsui-react-5.7.17.tgz: package/lib/DatePicker/Combo/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["min", "max", "type", "value", "format", "onError", "ModalProps"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import Combo from "./../../Picker/Combo";
import Modal from "./../Modal";
import { getDateDisplayValue } from "./../utils";

// 日期选择
import { jsx as _jsx } from "react/jsx-runtime";
export default /*#__PURE__*/forwardRef(function (_ref, ref) {
  var min = _ref.min,
    max = _ref.max,
    type = _ref.type,
    value = _ref.value,
    format = _ref.format,
    onError = _ref.onError,
    ModalProps = _ref.ModalProps,
    props = _objectWithoutProperties(_ref, _excluded);
  // 显示文本
  var displayValue = getDateDisplayValue({
    type: type,
    format: format,
    value: value
  });
  var rootRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current, _rootRef$current2, _rootRef$current3, _rootRef$current4, _rootRef$current5, _rootRef$current6;
    return {
      rootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.rootDOM,
      modalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.modalDOM,
      instance: instance.current,
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current3 = rootRef.current) === null || _rootRef$current3 === void 0 ? void 0 : _rootRef$current3.getRootDOM,
      getModalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current4 = rootRef.current) === null || _rootRef$current4 === void 0 ? void 0 : _rootRef$current4.getModalDOM,
      getInstance: function getInstance() {
        return instance.current;
      },
      close: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current5 = rootRef.current) === null || _rootRef$current5 === void 0 ? void 0 : _rootRef$current5.close,
      open: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current6 = rootRef.current) === null || _rootRef$current6 === void 0 ? void 0 : _rootRef$current6.open,
      // 显示文本
      displayValue: displayValue,
      getDisplayValue: function getDisplayValue(newValue) {
        return getDateDisplayValue({
          type: type,
          format: format,
          value: newValue || value
        });
      }
    };
  });
  return /*#__PURE__*/_jsx(Combo, _objectSpread(_objectSpread({
    value: displayValue,
    ModalComponent: Modal,
    ModalProps: _objectSpread({
      value: value,
      min: min,
      max: max,
      type: type,
      onError: onError
    }, ModalProps)
  }, props), {}, {
    ref: rootRef
  }));
});
